@@ -5,13 +5,13 @@ __email__ = "anton.feldmann@gmail.com"
 __author__ = "anton feldmann"
 
 from apu.datastructures.circularebuffer import CircularBuffer
-from apu.datastructures.dictionary import (Dictionary,
-                                           DictionaryWrapper)
 from apu.datastructures.enhanced_list import EnhancedList
 from apu.datastructures.memorywrapper import MemoryWrapper
+from apu.datastructures.dictionary import (Dictionary,
+                                           DictionaryWrapper)
 
 __all__ = ["CircularBuffer",
+           "MemoryWrapper",
            "Dictionary",
            "DictionaryWrapper",
-           "EnhancedList",
-           "MemoryWrapper"]
+           "EnhancedList"]
